@@ -1,16 +1,24 @@
 package HPC::Runner::Command::execute_job::Base;
 
-use Moose::Role;
-# use MooseX::App::Role;
+use MooseX::App::Role;
+use MooseX::Types::Path::Tiny qw/Path Paths AbsPath AbsFile/;
 
+with 'HPC::Runner::Command::execute_job::Utils::Plugin';
 with 'HPC::Runner::Command::execute_job::Utils::Log';
+with 'HPC::Runner::Command::execute_job::Logger::JSON';
+
 use Sys::Hostname;
+use Archive::Tar;
 
 =head2 Command Line Options
 
 =cut
 
 
+=head2 Internal Attriutes
+
+=cut
+
 =head3 job_scheduler_id
 
 Job Scheduler ID running the script. Passed to slurm for mail information
@@ -22,9 +30,15 @@ has 'job_scheduler_id' => (
     isa     => 'Str|Undef',
     default => sub {
         my $self = shift;
-        my $scheduler_id =  $ENV{SLURM_JOB_ID} || $ENV{SBATCH_JOB_ID} || $ENV{PBS_JOBID} || '';
-        if($self->can('task_id') && $self->task_id){
-          $scheduler_id = $scheduler_id . '_'.$self->task_id;
+        my $scheduler_id =
+             $ENV{SLURM_ARRAY_JOB_ID}
+          || $ENV{SLURM_JOB_ID}
+          || $ENV{SBATCH_JOB_ID}
+          || $ENV{PBS_JOBID}
+          || $ENV{JOB_ID}
+          || '';
+        if ( $self->can('task_id') && $self->task_id ) {
+            $scheduler_id = $scheduler_id . '_' . $self->task_id;
         }
         return $scheduler_id;
     },
@@ -36,11 +50,11 @@ q{This defaults to your current Job Scheduler ID. Ignore this if running on a si
 );
 
 has 'hostname' => (
-  is => 'rw',
-  isa => 'Str|Undef',
-  default => sub {
-    return hostname;
-  },
+    is      => 'rw',
+    isa     => 'Str|Undef',
+    default => sub {
+        return hostname;
+    },
 );
 
 has 'wait' => (
@@ -49,6 +63,14 @@ has 'wait' => (
     default => 0,
 );
 
+=head3 counter
+
+This is task_id counter. Batch index start and/or array_id get passed in on the command line
+But for instances where we are creating a threadpool of more than 1 task
+The counter keeps track
+
+=cut
+
 has 'counter' => (
     traits   => ['Counter'],
     is       => 'rw',
@@ -68,5 +90,4 @@ has 'jobref' => (
     default => sub { [ [] ] },
 );
 
-
 1;
