@@ -73,17 +73,18 @@ sub create_json_task {
     my $basename = $self->data_tar->basename('.tar.gz');
     my $data_dir = File::Spec->catdir( $basename, $job_meta->{jobname} );
 
-    $self->check_lock($data_dir);
-    $self->write_lock($data_dir);
+    if ( !$self->no_log_json ) {
+        $self->check_lock;
+        $self->write_lock;
 
-    $self->add_to_running( $data_dir, $task_obj );
+        $self->add_to_running( $data_dir, $task_obj );
 
-    $self->remove_lock($data_dir);
+        $self->lock_file->remove;
+    }
 
     return $task_obj;
 }
 
-
 ## keep this or no?
 ##TODO Create Mem profile file
 sub create_task_file {
@@ -148,9 +149,6 @@ sub update_json_task {
         }
     }
 
-    $self->check_lock($data_dir);
-    $self->write_lock($data_dir);
-
     my $task_obj = $self->get_from_running($data_dir);
     $task_obj->{exit_time}      = $self->table_data->{exit_time};
     $task_obj->{duration}       = $self->table_data->{duration};
@@ -169,11 +167,16 @@ sub update_json_task {
           $self->task_mem_data->{count}->{$stat};
     }
 
-    $self->remove_from_running($data_dir);
-    ##TODO Add in mem for job
-    my $complete = $self->add_to_complete( $data_dir, $task_obj );
+    if ( !$self->no_log_json ) {
+        $self->check_lock;
+        $self->write_lock;
+
+        $self->remove_from_running($data_dir);
+        ##TODO Add in mem for job
+        $self->add_to_complete( $data_dir, $task_obj );
+        $self->lock_file->remove;
+    }
 
-    $self->remove_lock($data_dir);
     return $task_obj;
 }
 
@@ -182,7 +185,6 @@ sub add_to_complete {
     my $data_dir  = shift;
     my $task_data = shift;
 
-
     my $c_file = File::Spec->catfile( $data_dir, 'complete.json' );
     my $json_obj = $self->read_json($c_file);
 
@@ -199,6 +201,7 @@ sub read_json {
 
     my $json_obj;
     my $text;
+    $self->archive->read( $self->data_tar );
     if ( $self->archive->contains_file($file) ) {
         $text = $self->archive->get_content($file);
         $json_obj = decode_json($text) if $text;
@@ -218,6 +221,7 @@ sub write_json {
     return unless $json_obj;
 
     my $json_text = encode_json($json_obj);
+    $self->archive->read( $self->data_tar );
     if ( $self->archive->contains_file($file) ) {
         $self->archive->replace_content( $file, $json_text );
     }
