@@ -18,39 +18,30 @@ sub build_task_deps {
     my $self               = shift;
     my $batch_scheduler_id = shift;
     my $dep_scheduler_id   = shift;
+
     # my $batch_task_index   = shift;
     # my $dep_task_index     = shift;
 
-    my $array_dep = [ $batch_scheduler_id, $dep_scheduler_id, ];
-
-    return $array_dep;
+    # my $array_dep = [ $batch_scheduler_id, $dep_scheduler_id, ];
+    #
+    # return $array_dep;
+    return $self->assign_scheduler_deps( $batch_scheduler_id,
+        $dep_scheduler_id );
 }
 
-# sub prepare_batch_indexes {
-#     my $self = shift;
-#
-#     return [
-#         {
-#             batch_index_start =>
-#               $self->jobs->{ $self->current_job }->{batch_index_start},
-#             batch_index_end =>
-#               $self->jobs->{ $self->current_job }->{batch_index_end},
-#         }
-#     ];
-# }
-
 sub prepare_batch_indexes {
     my $self = shift;
 
     return $self->jobs->{ $self->current_job }->batch_indexes;
 }
 
-##TODO FIX THIS
+##TODO Write Tests
 sub gen_batch_index_str {
     my $self = shift;
 
-    #TODO Check this
-    my $counter = $self->batch_counter - 1;
+    $DB::single = 2;
+    my $counter =
+      $self->job_counter - $self->jobs->{ $self->current_job }->{cmd_start} - 1;
 
     ## Cmds are 0 indexed
     ## The first command in a job file is 0
